.. Automatically generated by nengo-bones, do not edit this file directly

***********************
pytest-rng contributors
***********************

See https://github.com/nengo/pytest-rng/graphs/contributors
for a list of the people who have committed to pytest-rng.
Thank you for your contributions!
